# Honore-Tamer example

using Distributions, Parameters, JuMP, Cbc, Random, Plots, JLD, LaTeXStrings

include("ht_auxiliary.jl")

# Set up the mode
model = HTModel(T = 2)

# True parameters
β0 = 0.2
Π0 = ht_prior(model)

# True cell probabilities
make_cell_probabilities!(model, β0)
p0 = model.P * Π0

# Make plots
ix = 2 # history for conditioning variables in model.y[:, ix] (most recent at top)
β_grid = vcat(-3.0:0.001:2.0)
p_grid = zeros(length(β_grid), 2)
LP_limits!(p_grid, model, β_grid, p0, ix)
pl = p_grid[:, 1]
pu = p_grid[:, 2]
xx = β_grid[pl .< 1]
y1 = pu[pl .< 1]
y2 = pl[pl .< 1]
yy = 0.5 * (y1 + y2)
ll = yy .- y2
uu = y1 .- yy
plot(xx, [yy, yy], fillrange = [yy .- ll, yy .+ uu],
    c = 1, legend = false, xlims = (-3.0, 2.0), ylims = (0.0, 1.0), xlabel = "β")
plot!([-3.0, 2.0], [minimum(pl), minimum(pl)],
    linestyle = :dot, color = :black, linewidth = 2)
plot!([-3.0, 2.0], [maximum(pu[pu .< 1.0]), maximum(pu[pu .< 1.0])],
    linestyle = :dot, color = :black, linewidth = 2)
plot!([minimum(xx), minimum(xx)], [minimum(0.0), minimum(1.0)],
    linestyle = :dash, color = :gray, linewidth = 1)
plot!([maximum(xx), maximum(xx)], [minimum(0.0), minimum(1.0)],
    linestyle = :dash, color = :gray, linewidth = 1)
annotate!(1.75, maximum(pu[pu .< 1.0])+.05, L"p_U")
annotate!(1.75, minimum(pl[pu .< 1.0])+.05, L"p_L")
if ix == 2
    savefig("t2_y1_beta.pdf")
elseif ix == 3
    savefig("t2_y0_beta.pdf")
end
