# plot for local asymptotic comparisons

using Plots, Random, Distributions

Φ(x) = cdf(Normal(0.0, 1.0), x)
ϕ(x) = pdf(Normal(0.0, 1.0), x)

h = -4:.01:4
Random.seed!(1234567)
z = rand(Normal(0.0, 1.0), 10000000)

d0 = zeros(size(h))
d1 = zeros(size(h))

e0 = zeros(size(h))
e1 = zeros(size(h))
e2 = zeros(size(h))

for i in 1:length(h)

    a = max(0.0, h[i] + 2.0 * max(h[i], 0.0))
    b = h[i] + 2.0 * max(h[i], 0.0)

    c = 2.0 * max(0.0, h[i] + max(h[i], 0.0))
    d = 2.0 * (h[i] + max(h[i], 0.0))

    Z = z .+ h[i]
    p = mean((Z .* (1.0 .+ 2.0 .* Φ.(Z)) .+ 2.0 .* ϕ.(Z)) .> 0.0)

    d0[i] = a - b * Φ(h[i])
    d1[i] = a - b * p

    q = mean((Z .* (1.0 .+ 1.0 * Φ.(Z)) .+ 1.0 .* ϕ.(Z)) .> 0.0)
    e0[i] = c - d * Φ(h[i])
    e1[i] = c - d * q
    e2[i] = c - d * p

end

plot(h, d1, linewidth = 2, legend = false, xlabel = "h")
plot!(h, d0, linewidth = 2, linestyle = :dashdot)
savefig("local_risk.pdf")

plot(h, e1, linewidth = 2, legend = false, xlabel = "h")
plot!(h, e0, linewidth = 2, linestyle =:dashdot)
plot!(h, e2, linewidth = 2, linestyle =:dash)
savefig("local_regret.pdf")
